==> qtah-qt5-0.3.0.tar.gz: qtah-qt5-0.3.0/src/Graphics/UI/Qtah/Widgets/QProgressBar.hs <==
{-# LANGUAGE CPP, FlexibleContexts, FlexibleInstances, GeneralizedNewtypeDeriving, MultiParamTypeClasses, ScopedTypeVariables, TypeSynonymInstances, UndecidableInstances #-}
#if !MIN_VERSION_base(4,8,0)
{-# LANGUAGE OverlappingInstances #-}
#endif

---------- GENERATED FILE, EDITS WILL BE LOST ----------

{-# LANGUAGE NoMonomorphismRestriction #-}

module Graphics.UI.Qtah.Widgets.QProgressBar (
  QProgressBarValue (..),
  QProgressBarConstPtr (..),
  QProgressBarPtr (..),
  QProgressBarConst,
  QProgressBar,
  castConst,
  cast,
  downCastConst,
  downCast,
  new,
  newWithParent,
  alignment,
  format,
  invertedAppearance,
  isTextVisible,
  maximum,
  minimum,
  orientation,
  reset,
  resetFormat,
  setAlignment,
  setFormat,
  setInvertedAppearance,
  setMaximum,
  setMinimum,
  setOrientation,
  setRange,
  setTextDirection,
  setTextVisible,
  setValue,
  text,
  textDirection,
  value,
  valueChangedSignal,
  QProgressBarDirection (..),
  ) where

import Graphics.UI.Qtah.Generated.Widgets.QProgressBar
import Graphics.UI.Qtah.Internal.Listener
import qualified Graphics.UI.Qtah.Signal as QtahSignal
import Prelude ()
import qualified Prelude as HoppyP


castConst = toQProgressBarConst
cast = toQProgressBar
downCastConst = downToQProgressBarConst
downCast = downToQProgressBar

valueChangedSignal :: (QProgressBarPtr object) => QtahSignal.Signal object (HoppyP.Int -> HoppyP.IO ())
valueChangedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerInt_new fn'
    listenerInt_connectListener listener' object' "2valueChanged(int)"
  , QtahSignal.internalName = "QProgressBar::valueChanged (ListenerInt)"
  }

==> qtah-qt5-0.8.0.tar.gz: qtah-qt5-0.8.0/src/Graphics/UI/Qtah/Widgets/QProgressBar.hs <==
{-# LANGUAGE FlexibleContexts, FlexibleInstances, ForeignFunctionInterface, MonoLocalBinds, MultiParamTypeClasses, ScopedTypeVariables, TypeSynonymInstances, UndecidableInstances #-}
---------- GENERATED FILE, EDITS WILL BE LOST ----------

{-# LANGUAGE NoMonomorphismRestriction #-}

module Graphics.UI.Qtah.Widgets.QProgressBar (
  QProgressBarValue (..),
  QProgressBarConstPtr (..),
  QProgressBarPtr (..),
  QProgressBarConst,
  QProgressBar,
  castConst,
  cast,
  downCastConst,
  downCast,
  new,
  newWithParent,
  alignment,
  emitValueChanged,
  format,
  invertedAppearance,
  isTextVisible,
  maximum,
  minimum,
  orientation,
  reset,
  resetFormat,
  setAlignment,
  setFormat,
  setInvertedAppearance,
  setMaximum,
  setMinimum,
  setOrientation,
  setRange,
  setTextDirection,
  setTextVisible,
  setValue,
  text,
  textDirection,
  value,
  valueChangedSignal,
  QProgressBarDirection (..),
  ) where

import qualified Foreign.Hoppy.Runtime as QtahFHR
import Graphics.UI.Qtah.Generated.Widgets.QProgressBar
import Graphics.UI.Qtah.Internal.Listener
import qualified Graphics.UI.Qtah.Signal as QtahSignal
import Prelude (($), (>>))
import qualified Prelude as HoppyP
import qualified Prelude as QtahP


castConst = toQProgressBarConst
cast = toQProgressBar
downCastConst = downToQProgressBarConst
downCast = downToQProgressBar

valueChangedSignal :: (QProgressBarPtr object) => QtahSignal.Signal object (HoppyP.Int -> HoppyP.IO ())
valueChangedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerInt_new object' "2valueChanged(int)" fn'
    valid' <- listenerInt_isValid listener'
    if valid'
      then QtahP.fmap QtahP.Just $ QtahSignal.internalMakeConnection listener'
      else QtahFHR.delete listener' >> QtahP.return QtahP.Nothing
  , QtahSignal.internalName = "QProgressBar::valueChanged (ListenerInt)"
  }
